@@ -26,7 +26,7 @@ from gcloud.aio.datastore.value import Value
 if BUILD_GCLOUD_REST:
     from requests import Session
 else:
-    from aiohttp import ClientSession as Session   # type: ignore[no-redef]
+    from aiohttp import ClientSession as Session  # type: ignore[no-redef]
 
 
 try:
@@ -120,11 +120,15 @@ class Datastore:
         if operation == Operation.DELETE:
             return {operation.value: key.to_repr()}
 
+        mutation_properties = {}
+        for k, v in (properties or {}).items():
+            value = v if isinstance(v, cls.value_kind) else cls.value_kind(v)
+            mutation_properties[k] = value.to_repr()
+
         return {
             operation.value: {
                 'key': key.to_repr(),
-                'properties': {k: cls.value_kind(v).to_repr()
-                               for k, v in (properties or {}).items()},
+                'properties': mutation_properties,
             }
         }
 
